814df69886d2dc7c791db10417901a9768931c88
angie
  Mon Jun 1 17:16:44 2015 -0700
Added support for bigGenePred to anno* libs for hgVai and hgIntegrator.
While updating annoFormatVep.c to use column indices from autoSql instead of
hardcoding genePred indices, I found that I had been using an incorrect index
for strand anyway -- so I removed 3 lines of no-op code.
refs #15439

diff --git src/hg/inc/genePred.h src/hg/inc/genePred.h
index 31ba43a..b2462e3 100644
--- src/hg/inc/genePred.h
+++ src/hg/inc/genePred.h
@@ -314,18 +314,21 @@
 
 struct dnaSeq *genePredGetDna(char *database, struct genePred *gp,
                               boolean coding, enum dnaCase dnaCase);
 // Returns the DNA sequence associated with gene prediction.
 // Negative strand genes will return the sequence as read from the negative strand.
 // Optionally restrict to coding sequence only
 
 int genePredBaseToCodingPos(struct genePred *gp, int basePos,
                             boolean stranded, boolean *isCoding);
 // Given a genePred model and a single (0 based) base position, predict the 0-based
 // DNA (stranded) coding sequence pos.  Dividing this number by 3 should give the AA position!
 // Returns -1 when outside of coding exons unless OPTIONAL isCoding pointer to boolean is
 // provided. In that case, returns last valid position and sets isCoding to FALSE.
 
 struct genePred  *genePredFromBigGenePred( char *chrom, struct bigBedInterval *bb);
-/* build a genePred from a bigGenePred */
+/* build a genePred from a bigGenePred interval */
+
+struct genePred  *genePredFromBigGenePredRow(char **row);
+/* build a genePred from a bigGenePred row */
 #endif /* GENEPRED_H */